FincraCheckout class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
launchFincra(BuildContext _, {required String publicKey, required String amount, required String name, required String feeBearer, required String phoneNumber, required String currency, required String email, required void onSuccess(dynamic code), required void onError(dynamic code), required Function onClose, Function? onAbandoned, bool showLogs = false, String? reference})
→ Future
-